%define anolis_release 6
%global udevrules_prefix 60-

Name:          tpm2-tss
Version:       4.0.1
Release:       %{anolis_release}%{?dist}
Summary:       TPM2.0 Software Stack
License:       BSD and TCGL
URL:           https://github.com/tpm2-software/tpm2-tss
Source0:       https://github.com/tpm2-software/tpm2-tss/releases/download/%{version}/%{name}-%{version}.tar.gz

Patch0:        tpm2-tss-3.0.0-doxygen.patch
Patch1:        0001-esys-add-SM4-algorithm-support.patch
Patch2:        0001-add-bootstrap-file.patch

# CVE-2024-29040
# Tracking bug: https://security-tracker.debian.org/tracker/CVE-2024-29040
# Upstream fix: https://github.com/tpm2-software/tpm2-tss/commit/710cd0b6adf3a063f34a8e92da46df7a107d9a99
Patch3: Bugfix-for-CVE-2024-29040.patch
Patch4:        Hygon-Add-support-for-udev-to-create-tcm-de.patch
Patch5:        Hygon-add-ecc-encrypt-decrypt-support.patch

BuildRequires: make doxygen gcc gcc-c++
BuildRequires: json-c-devel libcurl-devel libgcrypt-devel openssl-devel libuuid-devel
BuildRequires: systemd systemd-rpm-macros
BuildRequires: pkgconfig
Requires(pre): shadow-utils

%description
%{name} is a software stack supporting Trusted Platform Module(TPM) 2.0 system
APIs. It sits between TPM driver and applications, providing TPM2.0 specified
APIs for applications to access TPM module through kernel TPM drivers.

%package        devel
Summary:        Headers and libraries for building apps that use tpm2-tss
Requires:       %{name} = %{version}-%{release}

%description    devel
This package contains headers and libraries required to build applications that
use %{name}.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -n %{name}-%{version} -p1

%build
./bootstrap
%configure --disable-static --disable-silent-rules \
           --with-udevrulesdir=%{_udevrulesdir} --with-udevrulesprefix=%{udevrules_prefix} \
           --with-runstatedir=%{_rundir} --with-tmpfilesdir=%{_tmpfilesdir} --with-sysusersdir=%{_sysusersdir}

sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool

%make_build

%install
%make_install
find %{buildroot}%{_libdir} -type f -name \*.la -delete

%generate_compatibility_deps

%pre
getent group tss >/dev/null || groupadd -f -g 59 -r tss
if ! getent passwd tss >/dev/null ; then
    if ! getent passwd 59 >/dev/null ; then
      useradd -r -u 59 -g tss -d /dev/null -s /sbin/nologin -c "Account used for TPM access" tss
    else
      useradd -r -g tss -d /dev/null -s /sbin/nologin -c "Account used for TPM access" tss
    fi
fi
exit 0

%ldconfig_scriptlets

%files
%dir %{abidir}
%license LICENSE
%{_sysconfdir}/tpm2-tss/
%{_libdir}/libtss2-mu.so.0*
%{_libdir}/libtss2-sys.so.1*
%{_libdir}/libtss2-esys.so.0*
%{_libdir}/libtss2-fapi.so.1*
%{_libdir}/libtss2-rc.so.0*
%{_libdir}/libtss2-tcti*.so.0*
%{_libdir}/libtss2-policy.so.0*
%{abidir}/libtss2-*.dump
%{_sysusersdir}/tpm2-tss.conf
%{_tmpfilesdir}/tpm2-tss-fapi.conf
%{_udevrulesdir}/%{udevrules_prefix}tpm-udev.rules

%files devel
%{_includedir}/tss2/
%{_libdir}/libtss2-mu.so
%{_libdir}/libtss2-sys.so
%{_libdir}/libtss2-esys.so
%{_libdir}/libtss2-fapi.so
%{_libdir}/libtss2-rc.so
%{_libdir}/libtss2-tcti*.so
%{_libdir}/libtss2-policy.so
%{_libdir}/pkgconfig/tss2-*.pc
%{_mandir}/man3/*.3.zst
%{_mandir}/man5/*.5.zst
%{_mandir}/man7/tss2*.7.zst

%files doc
%doc README.md CHANGELOG.md

%changelog
* Sat Oct 12 2024 chench <chench@hygon.cn> - 4.0.1-6
- Add support for udev to create tcm devices
- add ecc encrypt/decrypt support

* Fri Jul 12 2024 lidongyue <dongyue@nfschina.com> 4.0.1-5
- Fix CVE-2024-29040

* Thu Dec 28 2023 chench <chench@hygon.cn> - 4.0.1-4
- add SM4 algorithm support from upstream

* Wed Apr 12 2023 Shawn Wang <shawnwang@linux.alibaba.com> - 4.0.1-3
- Optimize the spec file

* Tue Mar 28 2023 mgb01105731 <mgb01105731@alibaba-inc.com> - 4.0.1-2
- Del Specific Fields

* Sat Feb 25 2023 Shawn Wang <shawnwang@linux.alibaba.com> - 4.0.1-1
- update to 4.0.1

* Wed Oct 12 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 3.2.0-2
- optimise spec file & add doc package

* Tue Mar 22 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 3.2.0-1
- init from upstream 3.2.0
